/*

Written by Aaron D Richmond, 16-05-2016

Inductive sensor mount for any 12mm diameter inductive sensor, fixes in place of the effector clamp for a E3DV6 hotend.

Some holes/fixings may need a drill run through them before screwing on the effector. 

*/

/*** RESOLUSION ***/
$fs=.3;
$fa=.3;

/*** VARIABLES ***/
clamp_thickness = 6;
clamp_diameter = 36;
E3DV6_slot = 12;
    
/*** MAIN ***/

union(){
    rotate([180,0,0])main();    
}

/*** SUB'S ***/

module main(){
    union(){
        effector_clamp();
        translate([0,-40+2,-29])sensor_mount();
        
        //hot end block
        //translate([0,0,-8-35])cube([10,10,10],center=true);
        //translate([0,0,-18.5-2])cylinder(r=22/2,h=31,center=true);
    }
}

module effector_clamp_main(){
    union(){
        hull(){
            cylinder(r=clamp_diameter/2,h=clamp_thickness,center=true);
            translate([0,-19,0])cube([14,5,clamp_thickness],center=true);
            translate([0,0,-34])linear_extrude(height=37-clamp_thickness)polygon(points=[[7,-26.5],[26,-2],[26,-1],[25,0],[24,1],[23,2],[-26,-2],[-26,-1],[-25,0],[-24,1],[-23,2],[-7,-26.5]]);
        }
    }
}

module effector_clamp(){
    union(){
        difference(){
            
            effector_clamp_main();
            
            //fixings (M3)
            for(x=[22/2,-22/2],y=[12.5/2,-12.5/2]){
                translate([x,y,0])cylinder(r=2.5/2,h=clamp_thickness+1,center=true);
            }
            
            //E3DV6 slot 
            hull(){
                for(y=[0,clamp_diameter]){
                    translate([0,y,0])cylinder(r=E3DV6_slot/2,h=100,center=true);
                }
            }      
                
            //center cutout
            hull(){
                for(y=[0,50]){
                    translate([0,y,-20-clamp_thickness/2])cylinder(r=36/2,h=40,center=true);
                }
            }          
            
            //fan fixings 
            for(y=[24/2,-24/2],z=[24/2,-24/2]){
                rotate([0,0,-37.8])translate([14.3,y-1,z-18])rotate([0,90,0])cylinder(r=2.6/2,h=15,center=true);
            }
            for(y=[24/2,-24/2],z=[24/2,-24/2]){
                rotate([0,0,37.8])translate([-14.3,y-1,z-18])rotate([0,-90,0])cylinder(r=2.6/2,h=15,center=true);
            }
            rotate([0,0,-37.8])translate([14.3,-1,-18])rotate([0,90,0])cylinder(r=28/2,h=25,center=true);
            rotate([0,0,37.8])translate([-14.3,-1,-18])rotate([0,-90,0])cylinder(r=28/2,h=25,center=true);
           
            //cleanup the ends
            translate([0,clamp_diameter-8,0])cube([50,30,200],center=true);
            translate([0,20,-23])cube([60,37.2,40],center=true);  
         
            //flatten out the edges of the fan
            rotate([0,0,-37.8])translate([12,18,-23])cube([10,40,40],center=true);
            rotate([0,0,37.8])translate([-12,18,-23])cube([10,40,40],center=true);
            
        }
    }
}

module sensor_mount_main(){
    union(){
        //main
        hull(){
            cylinder(r=22/2,h=10,center=true);
            translate([0,9,0])cube([14,5,10],center=true);
        }        
        translate([0,10,0])cube([14,5,10],center=true);      
    }
}

module sensor_mount(){
    union(){
        difference(){          
            sensor_mount_main();
            
            //bore
            cylinder(r=12.5/2,h=11,center=true);
        
        }
    }
}